==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/sv_SE/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokal konfiguration';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Teman';
$lang['locfiledit_onglet_lang'] = 'Språk';
$lang['locfiledit_onglet_plug'] = 'Personligt Plugin';
$lang['locfiledit_cant_save'] = 'Det går inte att skriva till aktuell fil. Kontrollera att mappen "local/" är skrivbar (chmod).';
$lang['locfiledit_newfile'] = 'Filen existerar inte så den kommer att skapas av LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Filen skrevs med framgång.';
$lang['locfiledit_show_default'] = 'Visa referens fil: ';
$lang['locfiledit_save_bak'] = 'En säkerhetskopia kommer skapas när du sparar.';
$lang['locfiledit_saved_bak'] = 'Säkerhetskopia skapad (%s)';
$lang['locfiledit_save_file'] = 'Spara fil';
$lang['locfiledit_choose_file'] = 'Välj fil add ändra';
$lang['locfiledit_edit'] = 'Ändra';
$lang['locfiledit_restore'] = 'Återställ säkerhetskopia';
$lang['locfiledit_restore_confirm'] = 'Vänligen bekräfta? Återställning kommer inte fungera till nästa gång.';
$lang['locfiledit_bak_loaded1'] = 'Säkerhetskopia laddad.';
$lang['locfiledit_bak_loaded2'] = 'Du måste spara filen för att återställa den.';
$lang['locfiledit_syntax_error'] = 'Syntax fel! Filen kan inte sparas.';
$lang['locfiledit_enable_editarea'] = 'Aktivera Skrivfält';
$lang['locfiledit_disable_editarea'] = 'Avaktivera Skrivfält';
$lang['locfiledit_new_tpl'] = 'Skapa ny fil';
$lang['locfiledit_new_filename'] = 'Fil namn';
$lang['locfiledit_model'] = 'Modell';
$lang['locfiledit_empty_page'] = 'Töm sida';
$lang['locfiledit_parent_directory'] = 'Nuvarande katalog';
$lang['locfiledit_filename_error'] = 'Förbjudna symboler i filnamnet.';
$lang['locfiledit_file_already_exists'] = 'Filen existerar redan.';
$lang['locfiledit_model_error'] = 'Du måste välja en modell.';
$lang['locfiledit_empty_filename'] = 'Du måste välja ett filnamn.';
$lang['locfiledit_webmaster_only'] = 'Endast webmasters kan skapa eller ändra lokala filer.';

?>

==> piwigo-2.5.1.zip: piwigo/plugins/LocalFilesEditor/language/sv_SE/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokal konfiguration';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Teman';
$lang['locfiledit_onglet_lang'] = 'Språk';
$lang['locfiledit_onglet_plug'] = 'Personligt Plugin';
$lang['locfiledit_cant_save'] = 'Det går inte att skriva till aktuell fil. Kontrollera att mappen "local/" är skrivbar (chmod).';
$lang['locfiledit_newfile'] = 'Filen existerar inte så den kommer att skapas av LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Filen skrevs med framgång.';
$lang['locfiledit_show_default'] = 'Visa referens fil: ';
$lang['locfiledit_save_bak'] = 'En säkerhetskopia kommer skapas när du sparar.';
$lang['locfiledit_saved_bak'] = 'Säkerhetskopia skapad (%s)';
$lang['locfiledit_save_file'] = 'Spara fil';
$lang['locfiledit_choose_file'] = 'Välj fil add ändra';
$lang['locfiledit_edit'] = 'Ändra';
$lang['locfiledit_restore'] = 'Återställ säkerhetskopia';
$lang['locfiledit_restore_confirm'] = 'Vänligen bekräfta? Återställning kommer inte fungera till nästa gång.';
$lang['locfiledit_bak_loaded1'] = 'Säkerhetskopia laddad.';
$lang['locfiledit_bak_loaded2'] = 'Du måste spara filen för att återställa den.';
$lang['locfiledit_syntax_error'] = 'Syntax fel! Filen kan inte sparas.';
$lang['locfiledit_new_tpl'] = 'Skapa ny fil';
$lang['locfiledit_new_filename'] = 'Fil namn';
$lang['locfiledit_model'] = 'Modell';
$lang['locfiledit_empty_page'] = 'Töm sida';
$lang['locfiledit_parent_directory'] = 'Nuvarande katalog';
$lang['locfiledit_filename_error'] = 'Förbjudna symboler i filnamnet.';
$lang['locfiledit_file_already_exists'] = 'Filen existerar redan.';
$lang['locfiledit_model_error'] = 'Du måste välja en modell.';
$lang['locfiledit_empty_filename'] = 'Du måste välja ett filnamn.';
$lang['locfiledit_webmaster_only'] = 'Endast webmasters kan skapa eller ändra lokala filer.';
?>
